@@ -1,4 +1,4 @@
-/* Copyright 2010--2016 The Tor Project
+/* Copyright 2010--2017 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.bridgedescs;
@@ -152,13 +152,12 @@ public class SanitizedBridgesWriter extends CollecTorMain {
 
     /* Read hex-encoded secrets for replacing IP addresses with hashes
      * from disk. */
-    this.secretsForHashingIpAddresses = new TreeMap<String, byte[]>();
+    this.secretsForHashingIpAddresses = new TreeMap<>();
     this.bridgeIpSecretsFile = new File(statsDirectory,
         "bridge-ip-secrets");
     if (this.bridgeIpSecretsFile.exists()) {
-      try {
-        BufferedReader br = new BufferedReader(new FileReader(
-            this.bridgeIpSecretsFile));
+      try (BufferedReader br = new BufferedReader(new FileReader(
+          this.bridgeIpSecretsFile))) {
         String line;
         while ((line = br.readLine()) != null) {
           String[] parts = line.split(",");
@@ -177,7 +176,6 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           byte[] secret = Hex.decodeHex(parts[1].toCharArray());
           this.secretsForHashingIpAddresses.put(month, secret);
         }
-        br.close();
         if (!this.persistenceProblemWithSecrets) {
           logger.debug("Read "
               + this.secretsForHashingIpAddresses.size() + " secrets for "
@@ -293,7 +291,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         /* Invalid IPv6 address. */
         return null;
       }
-      List<String> hexParts = new ArrayList<String>();
+      List<String> hexParts = new ArrayList<>();
       for (String doubleColonSeparatedPart : doubleColonSeparatedParts) {
         StringBuilder hexPart = new StringBuilder();
         String[] parts = doubleColonSeparatedPart.split(":", -1);
@@ -463,8 +461,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
 
     /* Parse the given network status line by line. */
     StringBuilder header = new StringBuilder();
-    SortedMap<String, String> scrubbedLines =
-        new TreeMap<String, String>();
+    boolean includesFingerprintLine = false;
+    SortedMap<String, String> scrubbedLines = new TreeMap<>();
     try {
       StringBuilder scrubbed = new StringBuilder();
       BufferedReader br = new BufferedReader(new StringReader(new String(
@@ -486,6 +484,18 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         } else if (line.startsWith("flag-thresholds ")) {
           header.append(line + "\n");
 
+        /* The authority fingerprint in the "fingerprint" line can go in
+         * unscrubbed. */
+        } else if (line.startsWith("fingerprint ")) {
+          if (!("fingerprint " + authorityFingerprint).equals(line)) {
+            logger.warn("Mismatch between authority fingerprint expected from "
+                + "file name (" + authorityFingerprint + ") and parsed from "
+                + "\"fingerprint\" line (\"" + line + "\").");
+            return;
+          }
+          header.append(line + "\n");
+          includesFingerprintLine = true;
+
         /* r lines contain sensitive information that needs to be removed
          * or replaced. */
         } else if (line.startsWith("r ")) {
@@ -524,14 +534,14 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           }
 
           /* Write scrubbed r line to buffer. */
-          byte[] hashedBridgeIdentity = DigestUtils.sha(fingerprintBytes);
+          byte[] hashedBridgeIdentity = DigestUtils.sha1(fingerprintBytes);
           String hashedBridgeIdentityBase64 = Base64.encodeBase64String(
               hashedBridgeIdentity).substring(0, 27);
           hashedBridgeIdentityHex = Hex.encodeHexString(
               hashedBridgeIdentity);
           String descriptorIdentifier = parts[3];
           String hashedDescriptorIdentifier = Base64.encodeBase64String(
-              DigestUtils.sha(Base64.decodeBase64(descriptorIdentifier
+              DigestUtils.sha1(Base64.decodeBase64(descriptorIdentifier
               + "=="))).substring(0, 27);
           String scrubbedAddress = scrubIpv4Address(address,
               fingerprintBytes,
@@ -581,13 +591,20 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         scrubbedLines.put(hashedBridgeIdentityHex, scrubbedLine);
         scrubbed = new StringBuilder();
       }
+      if (!includesFingerprintLine) {
+        header.append("fingerprint ").append(authorityFingerprint).append("\n");
+      }
 
       /* Check if we can tell from the descriptor publication times
        * whether this status is possibly stale. */
       SimpleDateFormat formatter = new SimpleDateFormat(
           "yyyy-MM-dd HH:mm:ss");
       formatter.setTimeZone(TimeZone.getTimeZone("UTC"));
-      if (formatter.parse(publicationTime).getTime()
+      if (null == mostRecentDescPublished) {
+        logger.warn("The bridge network status published at " + publicationTime
+            + " does not contain a single entry. Please ask the bridge "
+            + "authority operator to check!");
+      } else if (formatter.parse(publicationTime).getTime()
           - formatter.parse(mostRecentDescPublished).getTime()
           > 60L * 60L * 1000L) {
         logger.warn("The most recent descriptor in the bridge "
@@ -694,7 +711,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
          * read the fingerprint. */
         } else if (line.startsWith("or-address ")) {
           if (orAddresses == null) {
-            orAddresses = new ArrayList<String>();
+            orAddresses = new ArrayList<>();
           }
           orAddresses.add(line.substring("or-address ".length()));
 
@@ -728,13 +745,13 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               .replaceAll(" ", "").toLowerCase();
           byte[] fingerprintBytes = Hex.decodeHex(
               fingerprint.toCharArray());
-          hashedBridgeIdentity = DigestUtils.shaHex(fingerprintBytes)
+          hashedBridgeIdentity = DigestUtils.sha1Hex(fingerprintBytes)
               .toLowerCase();
           try {
             scrubbedAddress = scrubIpv4Address(address, fingerprintBytes,
                 published);
             if (orAddresses != null) {
-              scrubbedOrAddresses = new ArrayList<String>();
+              scrubbedOrAddresses = new ArrayList<>();
               for (String orAddress : orAddresses) {
                 String scrubbedOrAddress = scrubOrAddress(orAddress,
                     fingerprintBytes, published);
@@ -802,7 +819,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
                 + "expected: '" + line + "'.  Skipping descriptor.");
             return;
           }
-          scrubbed.append("extra-info-digest " + DigestUtils.shaHex(
+          scrubbed.append("extra-info-digest " + DigestUtils.sha1Hex(
               Hex.decodeHex(parts[1].toCharArray())).toUpperCase());
           if (parts.length > 2) {
             if (!Base64.isBase64(parts[2])) {
@@ -897,7 +914,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           StringBuilder familyLine = new StringBuilder("family");
           for (String s : line.substring(7).split(" ")) {
             if (s.startsWith("$")) {
-              familyLine.append(" $" + DigestUtils.shaHex(Hex.decodeHex(
+              familyLine.append(" $" + DigestUtils.sha1Hex(Hex.decodeHex(
                   s.substring(1).toCharArray())).toUpperCase());
             } else {
               familyLine.append(" " + s);
@@ -955,7 +972,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       if (start >= 0 && sig >= 0 && sig > start) {
         byte[] forDigest = new byte[sig - start];
         System.arraycopy(data, start, forDigest, 0, sig - start);
-        descriptorDigest = DigestUtils.shaHex(DigestUtils.sha(forDigest));
+        descriptorDigest = DigestUtils.sha1Hex(DigestUtils.sha1(forDigest));
       }
     } catch (UnsupportedEncodingException e) {
       /* Handle below. */
@@ -1115,7 +1132,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
                 + "'.  Skipping descriptor.");
             return;
           }
-          hashedBridgeIdentity = DigestUtils.shaHex(Hex.decodeHex(
+          hashedBridgeIdentity = DigestUtils.sha1Hex(Hex.decodeHex(
               parts[2].toCharArray())).toLowerCase();
           scrubbed = new StringBuilder("extra-info " + parts[1] + " "
               + hashedBridgeIdentity.toUpperCase() + "\n");
@@ -1192,7 +1209,9 @@ public class SanitizedBridgesWriter extends CollecTorMain {
             || line.startsWith("dirreq-")
             || line.startsWith("cell-")
             || line.startsWith("entry-")
-            || line.startsWith("exit-")) {
+            || line.startsWith("exit-")
+            || line.startsWith("hidserv-")
+            || line.startsWith("padding-counts ")) {
           scrubbed.append(line + "\n");
 
         /* When we reach the signature, we're done. Write the sanitized
@@ -1238,7 +1257,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       if (start >= 0 && sig >= 0 && sig > start) {
         byte[] forDigest = new byte[sig - start];
         System.arraycopy(data, start, forDigest, 0, sig - start);
-        descriptorDigest = DigestUtils.shaHex(DigestUtils.sha(forDigest));
+        descriptorDigest = DigestUtils.sha1Hex(DigestUtils.sha1(forDigest));
       }
     } catch (UnsupportedEncodingException e) {
       /* Handle below. */
@@ -1396,7 +1415,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
   public void cleanUpRsyncDirectory() throws ConfigurationException {
     long cutOffMillis = System.currentTimeMillis()
         - 3L * 24L * 60L * 60L * 1000L;
-    Stack<File> allFiles = new Stack<File>();
+    Stack<File> allFiles = new Stack<>();
     allFiles.add(new File(config.getPath(Key.RecentPath).toFile(),
         BRIDGE_DESCRIPTORS));
     while (!allFiles.isEmpty()) {
