@@ -1,4 +1,4 @@
-/* Copyright 2010--2016 The Tor Project
+/* Copyright 2010--2017 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.exitlists;
@@ -9,7 +9,6 @@ import org.torproject.collector.conf.ConfigurationException;
 import org.torproject.collector.conf.Key;
 import org.torproject.collector.cron.CollecTorMain;
 import org.torproject.descriptor.Descriptor;
-import org.torproject.descriptor.DescriptorParseException;
 import org.torproject.descriptor.DescriptorParser;
 import org.torproject.descriptor.DescriptorSourceFactory;
 import org.torproject.descriptor.ExitList;
@@ -28,7 +27,6 @@ import java.nio.file.Paths;
 import java.text.SimpleDateFormat;
 import java.util.Arrays;
 import java.util.Date;
-import java.util.List;
 import java.util.SortedSet;
 import java.util.Stack;
 import java.util.TimeZone;
@@ -73,30 +71,30 @@ public class ExitListDownloader extends CollecTorMain {
         EXITLISTS).toString();
     Date downloadedDate = new Date();
     String downloadedExitList = null;
-    try {
-      logger.debug("Downloading exit list...");
-      StringBuilder sb = new StringBuilder();
-      sb.append(Annotation.Torperf.toString());
-      sb.append("Downloaded " + dateTimeFormat.format(downloadedDate)
-          + "\n");
-      URL url = config.getUrl(Key.ExitlistUrl);
+    logger.debug("Downloading exit list...");
+    StringBuilder sb = new StringBuilder();
+    sb.append(Annotation.ExitList.toString());
+    sb.append("Downloaded " + dateTimeFormat.format(downloadedDate) + "\n");
+    URL url = config.getUrl(Key.ExitlistUrl);
+    try  {
       HttpURLConnection huc = (HttpURLConnection) url.openConnection();
       huc.setRequestMethod("GET");
+      huc.setReadTimeout(5000);
       huc.connect();
       int response = huc.getResponseCode();
       if (response != 200) {
-        logger.warn("Could not download exit list. Response code "
-            + response);
+        logger.warn("Could not download exit list. Response code {}",
+            response);
         return;
       }
-      BufferedInputStream in = new BufferedInputStream(
-          huc.getInputStream());
-      int len;
-      byte[] data = new byte[1024];
-      while ((len = in.read(data, 0, 1024)) >= 0) {
-        sb.append(new String(data, 0, len));
+      try (BufferedInputStream in = new BufferedInputStream(
+          huc.getInputStream())) {
+        int len;
+        byte[] data = new byte[1024];
+        while ((len = in.read(data, 0, 1024)) >= 0) {
+          sb.append(new String(data, 0, len));
+        }
       }
-      in.close();
       downloadedExitList = sb.toString();
       logger.debug("Finished downloading exit list.");
     } catch (IOException e) {
@@ -114,27 +112,28 @@ public class ExitListDownloader extends CollecTorMain {
     File tarballFile = Paths.get(outputPathName,
         tarballFormat.format(downloadedDate)).toFile();
 
+    DescriptorParser descriptorParser =
+        DescriptorSourceFactory.createDescriptorParser();
+    int parsedExitLists = 0;
+    int otherDescriptors = 0;
     long maxScanMillis = 0L;
-    try {
-      DescriptorParser descriptorParser =
-          DescriptorSourceFactory.createDescriptorParser();
-      List<Descriptor> parsedDescriptors =
-          descriptorParser.parseDescriptors(downloadedExitList.getBytes(),
-          tarballFile.getName());
-      if (parsedDescriptors.size() != 1
-          || !(parsedDescriptors.get(0) instanceof ExitList)) {
-        logger.warn("Could not parse downloaded exit list");
-        return;
-      }
-      ExitList parsedExitList = (ExitList) parsedDescriptors.get(0);
-      for (ExitList.Entry entry : parsedExitList.getEntries()) {
-        for (long scanMillis : entry.getExitAddresses().values()) {
-          maxScanMillis = Math.max(maxScanMillis, scanMillis);
+    for (Descriptor descriptor : descriptorParser.parseDescriptors(
+        downloadedExitList.getBytes(), null, tarballFile.getName())) {
+      if (descriptor instanceof ExitList) {
+        parsedExitLists++;
+        ExitList parsedExitList = (ExitList) descriptor;
+        for (ExitList.Entry entry : parsedExitList.getEntries()) {
+          for (long scanMillis : entry.getExitAddresses().values()) {
+            maxScanMillis = Math.max(maxScanMillis, scanMillis);
+          }
         }
+      } else {
+        otherDescriptors++;
       }
-    } catch (DescriptorParseException e) {
-      logger.warn("Could not parse downloaded exit list",
-          e);
+    }
+    if (parsedExitLists != 1 || otherDescriptors > 0) {
+      logger.warn("Could not parse downloaded exit list");
+      return;
     }
     if (maxScanMillis > 0L
         && maxScanMillis + 330L * 60L * 1000L < System.currentTimeMillis()) {
@@ -162,13 +161,13 @@ public class ExitListDownloader extends CollecTorMain {
     /* Write stats. */
     StringBuilder dumpStats = new StringBuilder("Finished downloading "
         + "exit list.\nLast three exit lists are:");
-    Stack<File> filesInInputDir = new Stack<File>();
+    Stack<File> filesInInputDir = new Stack<>();
     filesInInputDir.add(new File(outputPathName));
-    SortedSet<File> lastThreeExitLists = new TreeSet<File>();
+    SortedSet<File> lastThreeExitLists = new TreeSet<>();
     while (!filesInInputDir.isEmpty()) {
       File pop = filesInInputDir.pop();
       if (pop.isDirectory()) {
-        SortedSet<File> lastThreeElements = new TreeSet<File>();
+        SortedSet<File> lastThreeElements = new TreeSet<>();
         for (File f : pop.listFiles()) {
           lastThreeElements.add(f);
         }
@@ -198,8 +197,8 @@ public class ExitListDownloader extends CollecTorMain {
   public void cleanUpRsyncDirectory() throws ConfigurationException {
     long cutOffMillis = System.currentTimeMillis()
         - 3L * 24L * 60L * 60L * 1000L;
-    Stack<File> allFiles = new Stack<File>();
-    allFiles.add(new File(recentPathName, EXITLISTS));
+    Stack<File> allFiles = new Stack<>();
+    allFiles.add(new File(recentPathName));
     while (!allFiles.isEmpty()) {
       File file = allFiles.pop();
       if (file.isDirectory()) {
