@@ -535,6 +535,29 @@ public class SanitizedBridgesWriterTest {
         foundHidservLines);
   }
 
+  @Test
+  public void testExtraInfoDescriptorPaddingCountsRetained() throws Exception {
+    this.defaultExtraInfoDescriptorBuilder.insertBeforeLineStartingWith(
+        "transport ",
+        Arrays.asList("padding-counts 2017-05-10 01:48:43 (86400 s) "
+            + "bin-size=10000 write-drop=10000 write-pad=10000 "
+            + "write-total=10000 read-drop=10000 read-pad=10000 "
+            + "read-total=70000 enabled-read-pad=0 enabled-read-total=0 "
+            + "enabled-write-pad=0 enabled-write-total=0 "
+            + "max-chanpad-timers=0"));
+    this.runTest();
+    int foundPaddingCountsLines = 0;
+    if (!this.parsedExtraInfoDescriptors.isEmpty()) {
+      for (String line : this.parsedExtraInfoDescriptors.get(0)) {
+        if (line.startsWith("padding-counts ")) {
+          foundPaddingCountsLines++;
+        }
+      }
+    }
+    assertEquals("padding-counts line should have been retained.", 1,
+        foundPaddingCountsLines);
+  }
+
   @Test
   public void testExtraInfoDescriptorRouterSignatureLineSpace()
       throws Exception {
@@ -550,12 +573,13 @@ public class SanitizedBridgesWriterTest {
   public void testNetworkStatusDefault() throws Exception {
     this.runTest();
     List<String> expectedLines = Arrays.asList(
-        "@type bridge-network-status 1.1",
+        "@type bridge-network-status 1.2",
         "published 2016-06-30 23:40:28",
         "flag-thresholds stable-uptime=807660 stable-mtbf=1425164 "
             + "fast-speed=47000 guard-wfu=98.000% guard-tk=691200 "
             + "guard-bw-inc-exits=400000 guard-bw-exc-exits=402000 "
             + "enough-mtbf=1 ignoring-advertised-bws=0",
+        "fingerprint 4A0CCD2DDC7995083D73F5D667100C8A5831F16D",
         "r MeekGoogle iPdFhA9HzgxqT+YdgnlQsG+eRTQ "
             + "tpIv9cBFgU30vLcqDWyUF8/72Ao 2016-06-30 21:43:52 127.0.0.1 "
             + "1 0",
@@ -634,6 +658,19 @@ public class SanitizedBridgesWriterTest {
         + "in this descriptor type.", this.parsedNetworkStatuses.isEmpty());
   }
 
+  @Test
+  public void testNetworkStatusNoEntry() throws Exception {
+    this.defaultNetworkStatusBuilder.truncateAtLineStartingWith("r ");
+    this.runTest();
+    assertFalse("Skipped network status without entries.",
+        this.parsedNetworkStatuses.isEmpty());
+    for (String line : this.parsedNetworkStatuses.get(0)) {
+      if (line.startsWith("r ")) {
+        fail("Sanitized non-existent r line: " + line);
+      }
+    }
+  }
+
   @Test
   public void testNetworkStatusFromBifroest() throws Exception {
     this.defaultTarballBuilder.setTarballFileName(
