@@ -1,4 +1,4 @@
-/* Copyright 2016 The Tor Project
+/* Copyright 2016--2017 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector;
@@ -22,6 +22,7 @@ import org.junit.rules.TemporaryFolder;
 
 import java.io.BufferedWriter;
 import java.io.File;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
@@ -99,7 +100,7 @@ public class MainTest {
     Main.main(new String[]{conf.toString()});
     assertTrue(4_000L <= conf.length());
     changeFilePathsAndSetActivation(conf,
-        Key.TorperfActivated.name());
+        Key.OnionperfActivated.name());
     Main.main(new String[]{conf.toString()});
     waitSec(2);
   }
@@ -120,8 +121,10 @@ public class MainTest {
 
   private void changeFilePathsAndSetActivation(File file, String activation)
       throws Exception {
-    List<String> lines = Files.readAllLines(file.toPath());
-    BufferedWriter bw = Files.newBufferedWriter(file.toPath());
+    List<String> lines = Files.readAllLines(file.toPath(),
+        StandardCharsets.UTF_8);
+    BufferedWriter bw = Files.newBufferedWriter(file.toPath(),
+        StandardCharsets.UTF_8);
     File in = tmpf.newFolder();
     File out = tmpf.newFolder();
     String inStr = "in/";
